@@ -1,6 +1,6 @@
 // -*-mode:c++; c-style:k&r; c-basic-offset:4;-*-
 //
-// Copyright 2010-2018, Julian Catchen <jcatchen@illinois.edu>
+// Copyright 2010-2020, Julian Catchen <jcatchen@illinois.edu>
 //
 // This file is part of Stacks.
 //
@@ -2454,6 +2454,16 @@ write_results(map<int, MergedStack *> &m, map<int, Stack *> &u, map<int, Rem *>
                  << (*t).second << "\n";
         }
     }
+
+    time(&rawtime);
+    timeinfo = localtime(&rawtime);
+    strftime(date, 32, "%F %T", timeinfo);
+    log.str("");
+    log << "# ustacks completed on " << date << "\n";
+    tags << log.str();
+    snps << log.str();
+    alle << log.str();
+
     tags.close();
     snps.close();
     alle.close();
